\name{APTparam}
\alias{APTparam}

\title{ 
	Creates a 'APTparam' object for Cyto2APT or for Ax2APT functions.
}

\description{
	APTparam creates an internal object filled with all the arguments needed to run the Affymetrix Power Tools (APT) for Axiom or CytoScan. It allows a 'standard' were the call to the APT is generated by the R package affysv using some arguments and a 'custom' mode were the user can specify the command line arguments for the call to the APT.
}

\usage{
	APTparam(
		type  = "cytoscan", 
		level = "standard",
		...
	)
}

\arguments{
	\item{type}{
		[Mandatory] Technology used to create the .CEL files. It mus be 'axiom' or 'cytoscan'.
	}
	\item{level}{
		Type of argument-object. If 'standard' some other arguments must be filled like the path where the .CEL files are placed, the CDF file and others. If 'custom' only argument 'params' must be filled with the specific string containing all the argument for calling 'apt-copynumber-cyto' (for CytoScan .CEL files), for calling 'apt-geno-qc' (for Axiom) or for 'apt-probeset-genotype' (for Axiom). By default is set to 'standard'.
	}
	\item{cel.list}{
		[Mandatory] Path until the raw .CEL files.
	}
	\item{output.path}{
		[Mandatory] Output folder where the .cychp.txt files, output of 'apt-copynumber-cyto', or the genotype and call files, output of 'apt-probeset-genotype', will be stored.
	}
	\item{analysis.path}{
		[Mandatory] Path where the library files are stored. It must include the annotation file in db format.
	}
	\item{cdf}{
		Mandatory if level is set to 'standard' for CytoScan. Name of the CDF files passed to 'apt-copynumber-cyto'.
	}
	\item{chrX}{
		Mandatory if level is set to 'standard' for CytoScan. Name of the file containing the description of X chromosome passed to 'apt-copynumber-cyto'.
	}
	\item{chrY}{
		Mandatory if level is set to 'standard' for CytoScan. Name of the file containing the description of Y chromosome passed to 'apt-copynumber-cyto'.
	}
	\item{qca}{
		Mandatory if level is set to 'standard' for CytoScan. File that defines the parameters for the calculations of qc-call-rate and contrast-qc-rand that are used in the geno-qc analysis.
	}
	\item{qcc}{
		Mandatory if level is set to 'standard' for CytoScan. File that defines the probesets that are used by the geno-qc analysis
	}
	\item{annot.db}{
		Mandatory if level is set to 'standard' for CytoScan. NetAffx Annotation database file. It is a SQLite 3.x database.
	}
	\item{refmodel}{
		Mandatory if level is set to 'standard' for CytoScan. Affymetrix copy number reference generated from a set of hapmaps and normal blood samples (hdf5 format file).
	}
	\item{xml.config}{
		Mandatory if level is set to 'standard' for Axiom. 
	}
	\item{params}{
		Mandatory if level is set to 'custom'. String containing the arguments of the call to the corresponding tool, 'apt-copynumber-cyto' for CytoScan or 'apt-probeset-genotype' for Axiom.
	}
}

\details{
	~~
}

\value{
	The returned value is an object of class 'APTCopyNumberParam' for CytoScan or a list containing an object of class 'APTGenoQcParam' and a second object of class 'APTProbeSetGenotypeParam' for Axiom.
}

\examples{
# aptParam <- APTparam(
	# type="cytoscan", 
	# level="standard",
	# cel.list="C:\\Users\\Carles\\Desktop\\TEA_1de2", 
	# output.path="C:\\Users\\Carles\\Desktop\\APT_OUT", 
	# analysis.path="C:\\Users\\Carles\\Desktop\\lib_cytoHD",
	# cdf="CytoScanHD_Array.cdf", 
	# chrX="CytoScanHD_Array.chrXprobes", 
	# chrY="CytoScanHD_Array.chrYprobes", 
	# qca="CytoScanHD_Array.r1.qca", 
	# qcc="CytoScanHD_Array.r1.qcc", 
	# snp="CytoScanHD_Array.snplist.txt", 
	# annot.db="CytoScanHD_Array.na32.3.annot.db", 
	# refmodel="CytoScanHD_Array.na32.3.v1.REF_MODEL"
# )
}

\keyword{ APT }
\keyword{ Cyto2APT }
\keyword{ Ax2APT }
