\name{Ax2Mad}
\alias{Ax2Mad}

\title{ 
	Function to create a SnpMatrix or a file compatible with PLINK from Affymetrix Axiom 'intermediate' files (metrix, summary and genotype).
}

\description{
	This function uses the files created with Ax2APT, metrix, summary and genotype, to create a list containing a map file and a SnpMatrix with the genotype of each probe in the array. It can also be used to create a .tped file, compatible with PLINK (is in charge of the user to create the partner .tfam file).
}

\usage{
	Ax2Mad(calls.file, summary.file, annotation.file, output.name)
}

\arguments{
	\item{calls.file}{
		[Mandatory] Path until genotype file.
	}
	\item{summary.file}{
		[Mandatory] Path until summary file.
	}
	\item{annotation.file}{
		[Mandatory] NetAffx Annotation database file in CSV format.
	}
	\item{output.name}{
		[Mandatory] Path where the output files will be stored (for 'mad' as 'output.type') or the name of the generated file (for 'penncnv' as 'output.type').
	}
	\item{output.type}{
		By default 'mad'. It can be set to 'penncnv'. Use to determiner the type of file(s) the function will generate.
	}
	\item{metrix.file}{
		If generated, path until the metrix file.
	}
	\item{metrix.tm}{
		By default '97.0'. If specified metrix file, threshold to consider a probe well genotyped.
	}
	\item{verbose}{
		By default FALSE. If TRUE the function will shows messages indicating the process.
	}
}

\details{
	~~
}

\value{
	If 'output.type' is set to 'mad' it will generate a single file for each individual in the array. It 'output.type' is set to 'penncnv', the function will generate a single file, compatible with PennCNV.
}

\examples{
## To create files compatible with MAD/R-GADA
# Ax2Mad(
    # calls.file=paste0(output.path, .Platform$file.sep, "AxiomGT1.calls.txt"),
    # summary.file=paste0(output.path, .Platform$file.sep, "AxiomGT1.summary.txt"), 
    # annotation.file=paste0(path.lib, .Platform$file.sep, "Axiom_GW_Hu_SNP.na34.annot.csv"),
    # output.name="ax.mad",
    # output.type="mad"
# )

## To create a file compatible with PennCNV
# Ax2Mad(
    # calls.file=paste0(output.path, .Platform$file.sep, "AxiomGT1.calls.txt"),
    # summary.file=paste0(output.path, .Platform$file.sep, "AxiomGT1.summary.txt"), 
    # annotation.file=paste0(path.lib, .Platform$file.sep, "Axiom_GW_Hu_SNP.na34.annot.csv"),
    # output.name="ax",
    # output.type="penncnv"
# )
}

\keyword{ APT }
\keyword{ APTparam }
\keyword{ Ax2APT }
