\name{Ax2SnpMatrix}
\alias{Ax2SnpMatrix}

\title{ 
	Function to create a SnpMatrix or a file compatible with PLINK from Affymetrix Axiom 'intermediate' files (metrix, summary and genotype).
}

\description{
	This function uses the files created with Ax2APT, metrix, summary and genotype, to create a list containing a map file and a SnpMatrix with the genotype of each probe in the array. It can also be used to create a .tped file, compatible with PLINK (is in charge of the user to create the partner .tfam file).
}

\usage{
	Ax2SnpMatrix(calls.file, annotation.file, output.type, output.name, verbose)
}

\arguments{
	\item{calls.file}{
		[Mandatory] Location where the 'intermediate' files (metrix, summary and genotype) generated by Ax2APT.
	}
	\item{annotation.file}{
		[Mandatory] NetAffx Annotation database file in CSV format.
	}
	\item{output.type}{
		By default '4'. If the package is run over an OS compatible with the R package 'parallel', number of .CEL files that will be processed at the same time.
	}
	\item{output.name}{
		If 'output.type' is set to 'plink', it must contain the name of the output .tped file (with no extension).
	}
	\item{verbose}{
		By default FALSE. If TRUE the function will shows messages indicating the process.
	}
}

\details{
	~~
}

\value{
	If 'output.type' is set to 'snpmatrix' it will return a list containing a slot 'map' with the array annotation as a 'data.frame'  and a slot 'genotype' with a SnpMatrix. If the 'output.type' is set to 'plink' it will return NA.
}

\examples{
## To create a SnpMatrix Container (a list with a map and a SnpMatrix)
# smc <- Ax2SnpMatrix(
    # calls.file=paste0(output.path, .Platform$file.sep, "AxiomGT1.calls.txt"),
    # annotation.file=paste0(path.lib, .Platform$file.sep, "Axiom_GW_Hu_SNP.na34.annot.csv"),
    # output.type="snpmatrix"
# )

## To create the .tped file compatible with PLINK
# Ax2SnpMatrix(
    # calls.file=paste0(output.path, .Platform$file.sep, "AxiomGT1.calls.txt"),
    # annotation.file=paste0(path.lib, .Platform$file.sep, "Axiom_GW_Hu_SNP.na34.annot.csv"),
    # output.type="plink",
    # output.name="ax"
# )
}

\keyword{ APT }
\keyword{ APTparam }
\keyword{ Ax2APT }
