\name{Cyto2SnpMatrix}
\alias{Cyto2SnpMatrix}

\title{ 
	Function to create a SnpMatrix or a file compatible with PLINK from Affymetrix CytoScan (HD/750K) .CEL files.
}

\description{
	This function uses the files created with Cyto2APT to create a list containing a map file and a SnpMatrix with the genotype of each probe in the array. It can also be used to create a .tped file, compatible with PLINK (is in charge of the user to create the partner .tfam file).
}

\usage{
	Cyto2SnpMatrix(cychp.files, annotation.file, output.type, output.name, verbose)
}

\arguments{
	\item{cychp.files}{
		[Mandatory] Location where the .cychp.txt files (obtained from Cyto2APT) are placed.
	}
	\item{annotation.file}{
		[Mandatory] NetAffx Annotation database file in CSV format.
	}
	\item{output.type}{
		By default 'snpmatrix'. It can be set to 'plink'. Use to determiner the type of object/file the function will generate.
	}
	\item{output.name}{
		If 'output.type' is set to 'plink', it must contain the name of the output .tped file (with no extension).
	}
	\item{verbose}{
		By default FALSE. If TRUE the function will shows messages indicating the process.
	}
}

\details{
	~~
}

\value{
	If 'output.type' is set to 'snpmatrix' it will return a list containing a slot 'map' with the array annotation as a 'data.frame'  and a slot 'genotype' with a SnpMatrix. If the 'output.type' is set to 'plink' it will return NA.
}

\examples{
## To create a SnpMatrix Container (a list with a map and a SnpMatrix)
# smc <- Cyto2SnpMatrix(
	# cychp.files="C:/Users/brge/Desktop/APT_OUT", 
	# annotation.file="C:/Users/brge/Desktop/lib_cytoHD/CytoScanHD_Array.na32.3.annot.csv", 
	# output.type="snpmatrix"
# )

## To create the .tped file compatible with PLINK
# Cyto2SnpMatrix(
	# cychp.files="C:/Users/brge/Desktop/APT_OUT", 
	# annotation.file="C:/Users/brge/Desktop/lib_cytoHD/CytoScanHD_Array.na32.3.annot.csv", 
	# output.type="plink",
	# output.name="ASD"
# )
}

\keyword{ APT }
\keyword{ APTparam }
\keyword{ Ax2APT }
