\name{Gw2Mad}
\alias{Gw2Mad}

\title{ 
	Function to create compatible files with MAD or PennCNV from Affymetrix GenomeWide SNP (5.0/6.0) .CEL files.
}

\description{
	This function uses the raw .CEL files from both GenomeWide SNP 5.0 and 6.0 arrays to create a file for each individual compatible with the R packages MAD and R-GADA. It can also be used to create a compatible file with PennCNV.
}

\usage{
	Gw2Mad(cychp.files, output.name, annotation.file, output.type, cychp.attime, bottom.quantile, top.quantile, verbose)
}

\arguments{
	\item{cychp.files}{
		[Mandatory] Location where the .cychp.txt files (obtained from Cyto2APT) are placed.
	}
	\item{output.name}{
		If 'output.type' is set to 'mad', location where the files compatible with MAD/R-GADa will be saved. If 'output.type' is set to 'penncnv', name of the generated file.
	}
	\item{annotation.file}{
		[Mandatory] NetAffx Annotation database file in CSV format.
	}
	\item{output.type}{
		By default 'mad'. It can be set to 'penncnv'. Use to determiner the type of file(s) the function will generate.
	}
	\item{cychp.attime}{
		By default '4'. If the package is run over an OS compatible with the R package 'parallel', number of cychp.txt files that will be processed at the same time.
	}
	\item{bottom.quantile}{
		By default '0.25'. Bottom threshold on BAF quantile normalization.
	}
	\item{top.quantile}{
		By default '0.75'. Top threshold on BAF quantile normalization.
	}
	\item{verbose}{
		By default FALSE. If TRUE the function will shows messages indicating the process.
	}
}

\details{
	~~
}

\value{
	If 'output.type' is set to 'mad' it will generate a single file for each individual in the array. It 'output.type' is set to 'penncnv', the function will generate a single file, compatible with PennCNV.
}

\examples{
## To create files compatible with MAD/R-GADA
# Cyto2Mad(
	# cychp.files="C:/Users/brge/Desktop/APT_OUT",
	# output.name="C:/Users/brge/Desktop/MAD",
	# annotation.file="C:/Users/brge/Desktop/lib_cytoHD/CytoScanHD_Array.na32.3.annot.csv", 
	# output.type="mad",
# )

## To create files compatible with PennCNV
# Cyto2Mad(
	# cychp.files="C:/Users/brge/Desktop/APT_OUT",
	# output.name="C:/Users/brge/Desktop/ASD",
	# annotation.file="C:/Users/brge/Desktop/lib_cytoHD/CytoScanHD_Array.na32.3.annot.csv", 
	# output.type="penncnv",
# )
}

\keyword{ APT }
\keyword{ APTparam }
\keyword{ Ax2APT }
