\name{Gw2SnpMatrix}
\alias{Gw2SnpMatrix}

\title{ 
	Function to create a SnpMatrix or a file compatible with PLINK from Affymetrix GenomeWide SNP (6.0/5.0) .CEL files.
}

\description{
	This function uses the raw .CEL files from both GenomeWide SNP 5.0 and 6.0 arrays to create a list containing a map file and a SnpMatrix with the genotype of each probe in the array. It can also be used to create a .tped file, compatible with PLINK (is in charge of the user to create the partner .tfam file).
}

\usage{
	Gw2SnpMatrix(cel.files, cel.platform, cel.attime, cel.validate, output.type, output.type, verbose)
}

\arguments{
	\item{cel.files}{
		[Mandatory] Location where the .cychp.txt files (obtained from Cyto2APT) are placed.
	}
	\item{cel.platform}{
		By default 'affy6', it expects raw .CEL files from GenomeWide SNP 6.0. Can be set to 'affy5' to use raw .CEL files from GenomeWide SNP 5.0.
	}
	\item{cel.attime}{
		By default '4'. If the package is run over an OS compatible with the R package 'parallel', number of .CEL files that will be processed at the same time.
	}
	\item{cel.validate}{
		By default 'TRUE'. Can be set to 'FALSE' to avoid the step 'validation of .CEL files' from 'clrmm'.
	}
	\item{output.type}{
		By default 'snpmatrix'. It can be set to 'plink'. Use to determiner the type of object/file the function will generate.
	}
	\item{output.type}{
		If 'output.type' is set to 'plink', it must contain the name of the output .tped file (with no extension).
	}
	\item{verbose}{
		By default FALSE. If TRUE the function will shows messages indicating the process.
	}
}

\details{
	~~
}

\note{
	Since 'Gw2SnpMatrix' uses the R package 'crlmm', the output object/file will not contain information for X and Y chromosomes.
}

\value{
	If 'output.type' is set to 'snpmatrix' it will return a list containing a slot 'map' with the array annotation as a 'data.frame'  and a slot 'genotype' with a SnpMatrix. If the 'output.type' is set to 'plink' it will return NA.
}

\examples{
## To create a SnpMatrix Container (a list with a map and a SnpMatrix)
# smc <- Gw2SnpMatrix(
    # cel.files="C:/Users/brge/Desktop/GW6",
    # output.type="snpmatrix"
# )

## To create the .tped file compatible with PLINK
# Gw2SnpMatrix(
    # cel.files="C:/Users/brge/Desktop/GW6",
    # output.type="plink",
    # output.name="C:/Users/brge/Desktop/PRAD"
# )
}

\keyword{ APT }
\keyword{ APTparam }
\keyword{ Ax2APT }
